@@ -149,6 +149,7 @@ def _initPropertyList_Display(threedee):
 
 def _initPropertyList_VolumeOpts(threedee):
     plist = ['custom_volume',
+             'channel',
              'interpolation',
              'custom_cmap',
              'cmapResolution',
@@ -308,6 +309,19 @@ def _initPropertyList_MIPOpts(threedee):
             'absolute']
 
 
+def _initPropertyList_VolumeRGBOpts(threedee):
+    return ['custom_volume',
+            'interpolation',
+            'rColour',
+            'gColour',
+            'bColour',
+            'suppressR',
+            'suppressG',
+            'suppressB',
+            'suppressA',
+            'suppressMode']
+
+
 def _initWidgetSpec_Display(threedee):
     return {
         'name'        : props.Widget('name'),
@@ -372,6 +386,7 @@ def _initWidgetSpec_VolumeOpts(threedee):
 
     return {
         'custom_volume'  : _NiftiOpts_VolumeWidget,
+        'channel'        : props.Widget('channel'),
         'volume'         : props.Widget(
             'volume',
             showLimits=False,
@@ -795,6 +810,35 @@ def _initWidgetSpec_MIPOpts(threedee):
     }
 
 
+def _initWidgetSpec_VolumeRGBOpts(threedee):
+
+    return {
+        'custom_volume'  : _NiftiOpts_VolumeWidget,
+        'volume'         : props.Widget(
+            'volume',
+            showLimits=False,
+            enabledWhen=lambda o: o.overlay.ndim > 3,
+            spinWidth=6),
+        'volumeDim'      : props.Widget(
+            'volumeDim',
+            showLimits=False,
+            slider=False,
+            enabledWhen=lambda o: o.overlay.ndim > 4,
+            spinWidth=2),
+        'interpolation'  : props.Widget(
+            'interpolation',
+            labels=strings.choices['VolumeOpts.interpolation']),
+        'rColour'      : props.Widget('rColour'),
+        'gColour'      : props.Widget('gColour'),
+        'bColour'      : props.Widget('bColour'),
+        'suppressR'    : props.Widget('suppressR'),
+        'suppressG'    : props.Widget('suppressG'),
+        'suppressB'    : props.Widget('suppressB'),
+        'suppressA'    : props.Widget('suppressA'),
+        'suppressMode' : props.Widget('suppressMode'),
+    }
+
+
 def _ColourMapOpts_ColourMapWidget(
         target,
         parent,
