@@ -235,9 +235,9 @@ class GLVolume(glimageobject.GLImageObject):
             self.smoothFilter.set(kernSize=self.opts.smoothing * 2)
 
             self.renderTexture1 = textures.RenderTexture(
-                self.name, gl.GL_LINEAR, rttype='cd')
+                self.name, interp=gl.GL_LINEAR, rttype='cd')
             self.renderTexture2 = textures.RenderTexture(
-                self.name, gl.GL_LINEAR, rttype='cd')
+                self.name, interp=gl.GL_LINEAR, rttype='cd')
 
         # This attribute is used by the
         # updateShaderState method to
@@ -276,11 +276,11 @@ class GLVolume(glimageobject.GLImageObject):
         self.removeDisplayListeners()
 
         self.imageTexture.deregister(self.name)
-        glresources.delete(self.imageTexture.getTextureName())
+        glresources.delete(self.imageTexture.name)
 
         if self.clipTexture is not None:
             self.clipTexture.deregister(self.name)
-            glresources.delete(self.clipTexture.getTextureName())
+            glresources.delete(self.clipTexture.name)
 
         self.colourTexture   .destroy()
         self.negColourTexture.destroy()
@@ -361,6 +361,7 @@ class GLVolume(glimageobject.GLImageObject):
                              self._useNegativeCmapChanged)
         opts    .addListener('invert',           name, self._invertChanged)
         opts    .addListener('volume',           name, self._volumeChanged)
+        opts    .addListener('channel',          name, self._channelChanged)
         opts    .addListener('interpolation',    name,
                              self._interpolationChanged)
         opts    .addListener('transform',        name, self._transformChanged)
@@ -391,7 +392,7 @@ class GLVolume(glimageobject.GLImageObject):
             opts.addListener('clipInclination', name, self._clipping3DChanged)
 
         # GLVolume instances need to keep track of whether
-        # the volume property of their corresponding
+        # the volume/channel properties of their corresponding
         # VolumeOpts instance is synced to other VolumeOpts
         # instances - if it is, there an ImageTexture for
         # the image may already exist (i.e. have been
@@ -412,6 +413,9 @@ class GLVolume(glimageobject.GLImageObject):
             opts.addSyncChangeListener('volume',
                                        name,
                                        self._imageSyncChanged)
+            opts.addSyncChangeListener('channel',
+                                       name,
+                                       self._imageSyncChanged)
 
 
     def removeDisplayListeners(self):
@@ -438,6 +442,7 @@ class GLVolume(glimageobject.GLImageObject):
         opts    .removeListener(          'cmapResolution',          name)
         opts    .removeListener(          'invert',                  name)
         opts    .removeListener(          'volume',                  name)
+        opts    .removeListener(          'channel',                 name)
         opts    .removeListener(          'interpolation',           name)
         opts    .removeListener(          'transform',               name)
         opts    .removeListener(          'displayXform',            name)
@@ -458,7 +463,8 @@ class GLVolume(glimageobject.GLImageObject):
             opts.removeListener('clipInclination', name)
 
         if self.__syncListenersRegistered:
-            opts.removeSyncChangeListener('volume', name)
+            opts.removeSyncChangeListener('volume',  name)
+            opts.removeSyncChangeListener('channel', name)
 
 
     def testUnsynced(self):
@@ -469,10 +475,12 @@ class GLVolume(glimageobject.GLImageObject):
         ``GLVolume`` instance needs to create its own image texture;
         returns ``False`` otherwise.
         """
-        is4D = len(self.image.shape) >= 4 and self.image.shape[3] > 1
+        is4D  = len(self.image.shape) >= 4 and self.image.shape[3] > 1
+        isRGB = self.image.nvals > 1
 
-        return (self.opts.getParent() is None or
-                (is4D and not self.opts.isSyncedToParent('volume')))
+        return ((self.opts.getParent() is None)                      or
+                (is4D  and not self.opts.isSyncedToParent('volume')) or
+                (isRGB and not self.opts.isSyncedToParent('channel')))
 
 
     def updateShaderState(self, *args, **kwargs):
@@ -545,11 +553,11 @@ class GLVolume(glimageobject.GLImageObject):
 
         if self.imageTexture is not None:
 
-            if self.imageTexture.getTextureName() == texName:
+            if self.imageTexture.name == texName:
                 return None
 
             self.imageTexture.deregister(self.name)
-            glresources.delete(self.imageTexture.getTextureName())
+            glresources.delete(self.imageTexture.name)
 
         if opts.interpolation == 'none': interp = gl.GL_NEAREST
         else:                            interp = gl.GL_LINEAR
@@ -559,10 +567,11 @@ class GLVolume(glimageobject.GLImageObject):
 
         self.imageTexture = glresources.get(
             texName,
-            textures.ImageTexture,
+            textures.createImageTexture,
             texName,
             self.image,
             interp=interp,
+            channel=opts.channel,
             volume=opts.index()[3:],
             normaliseRange=normRange,
             notify=False)
@@ -622,7 +631,7 @@ class GLVolume(glimageobject.GLImageObject):
 
         if self.clipTexture is not None:
             self.clipTexture.deregister(self.name)
-            glresources.delete(self.clipTexture.getTextureName())
+            glresources.delete(self.clipTexture.name)
             self.clipTexture = None
 
         if clipImage is None:
@@ -719,10 +728,10 @@ class GLVolume(glimageobject.GLImageObject):
         # Initialise and resize
         # the offscreen textures
         for rt in [self.renderTexture1, self.renderTexture2]:
-            if rt.getSize() != (sw, sh):
-                rt.setSize(sw, sh)
+            if rt.shape != (sw, sh):
+                rt.shape = sw, sh
 
-            with rt.bound():
+            with rt.target():
                 gl.glClearColor(0, 0, 0, 0)
                 gl.glClear(gl.GL_COLOR_BUFFER_BIT | gl.GL_DEPTH_BUFFER_BIT)
 
@@ -824,11 +833,45 @@ class GLVolume(glimageobject.GLImageObject):
         else:
             clipCoordXform = transform.concat(
                 self.clipOpts.getTransform('display', 'texture'),
-                self.opts    .getTransform('texture', 'display'))
+                self.opts    .getTransform('texture', 'display'),
+                self.imageTexture.invTexCoordXform)
 
         return clipCoordXform
 
 
+    def generateVertices2D(self, zpos, axes, bbox=None):
+        """Overrides :meth:`.GLImageObject.generateVertices2D`.
+
+        Appliies the :meth:`.ImageTextureBase.texCoordXform` to the texture
+        coordinates - this is performed to support 2D images/textures.
+        """
+
+        vertices, voxCoords, texCoords = \
+            glimageobject.GLImageObject.generateVertices2D(
+                self, zpos, axes, bbox)
+
+        texCoords = transform.transform(
+            texCoords, self.imageTexture.texCoordXform)
+
+        return vertices, voxCoords, texCoords
+
+
+    def generateVertices3D(self, bbox=None):
+        """Overrides :meth:`.GLImageObject.generateVertices3D`.
+
+        Appliies the :meth:`.ImageTextureBase.texCoordXform` to the texture
+        coordinates - this is performed to support 2D images/textures.
+        """
+
+        vertices, voxCoords, texCoords = \
+            glimageobject.GLImageObject.generateVertices3D(self, bbox)
+
+        texCoords = transform.transform(
+            texCoords, self.imageTexture.texCoordXform)
+
+        return vertices, voxCoords, texCoords
+
+
     def _alphaChanged(self, *a):
         """Called when the :attr:`.Display.alpha` property changes. """
 
@@ -934,6 +977,7 @@ class GLVolume(glimageobject.GLImageObject):
         else:                            normRange = None
 
         self.imageTexture.set(volume=opts.index()[3:],
+                              channel=opts.channel,
                               interp=interp,
                               volRefresh=volRefresh,
                               normaliseRange=normRange)
@@ -942,6 +986,13 @@ class GLVolume(glimageobject.GLImageObject):
             self.clipTexture.set(interp=interp)
 
 
+    def _channelChanged(self, *a, **kwa):
+        """Called when the :attr:`.NiftiOpts.channel` changes.
+        Refreshes the texture.
+        """
+        self._volumeChanged()
+
+
     def _interpolationChanged(self, *a):
         """Called when the :attr:`.NiftiOpts.interpolation` property changes.
         """
